var indexSectionsWithContent =
{
  0: "%abcdgilmoprs",
  1: "l",
  2: "o",
  3: "abcdgimprs",
  4: "dl",
  5: "l",
  6: "%"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "groups",
  6: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Modules",
  6: "Pages"
};

